{ pkgs, lib, ... }:
{
  # support power features such as suspend to ram
  powerManagement.enable = true;
  # tune power saving options on boot
  powerManagement.powertop.enable = true;
  # thermald proactively prevents overheating on intel CPUs and works well with other tools
  services.thermald.enable = true;
  # power-profile-daemon for power management
  services.power-profiles-daemon.enable = true;
  # manage fans for macbook devices
  services.mbpfan.enable = true;

  # better performance than the actual intel driver
  services.xserver.videoDrivers = [ "modesetting" ];

  hardware.apple-t2.kernelChannel = "latest";
  hardware.apple-t2.firmware.enable = true;

  environment.variables = {
    LIBVA_DRIVER_NAME= "iHD";
    VDPAU_DRIVER = "va_gl";
  };

  environment.systemPackages = with pkgs; [ intel-gpu-tools ];

  boot.kernelParams = [
    # enable the i915 sandybridge framebuffer compression (475mw savings)
    "i915.enable_fbc=1"
    "i915.enable_gvt=1"
  ];
}
